==> vertigo-dynamo-impl-0.5.2.jar: io/vertigo/dynamo/plugins/environment/registries/facet/FacetDynamicRegistryPlugin.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.plugins.environment.registries.facet;

import io.vertigo.dynamo.impl.environment.kernel.model.DynamicDefinition;
import io.vertigo.dynamo.plugins.environment.registries.AbstractDynamicRegistryPlugin;

/**
 * @author pchretien
 */
public final class FacetDynamicRegistryPlugin extends AbstractDynamicRegistryPlugin<FacetGrammar> {
	/**
	 * Constructeur.
	 */
	public FacetDynamicRegistryPlugin() {
		super(new FacetGrammar());
	}

	/** {@inheritDoc} */
	public void onDefinition(final DynamicDefinition xdefinition) {
		//		if (getGrammar().fileInfoDefinition.equals(xdefinition.getEntity())) {
		//			//Seuls les taches sont gérées.
		//			final FileInfoDefinition definition = createFileDefinition(xdefinition);
		//			Home.getNameSpace().registerDefinition(definition, FileInfoDefinition.class);
		//		}
	}
}

==> vertigo-dynamo-impl-0.7.4.jar: io/vertigo/dynamo/plugins/environment/registries/facet/FacetDynamicRegistryPlugin.java <==
/**
 * vertigo - simple java starter
 *
 * Copyright (C) 2013, KleeGroup, direction.technique@kleegroup.com (http://www.kleegroup.com)
 * KleeGroup, Centre d'affaire la Boursidiere - BP 159 - 92357 Le Plessis Robinson Cedex - France
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.vertigo.dynamo.plugins.environment.registries.facet;

import io.vertigo.dynamo.impl.environment.kernel.model.DynamicDefinition;
import io.vertigo.dynamo.plugins.environment.registries.AbstractDynamicRegistryPlugin;

/**
 * @author pchretien
 */
public final class FacetDynamicRegistryPlugin extends AbstractDynamicRegistryPlugin {
	/**
	 * Constructeur.
	 */
	public FacetDynamicRegistryPlugin() {
		super(FacetGrammar.GRAMMAR);
	}

	/** {@inheritDoc} */
	@Override
	public void onDefinition(final DynamicDefinition xdefinition) {
		//		if (getGrammar().fileInfoDefinition.equals(xdefinition.getEntity())) {
		//			//Seuls les taches sont gérées.
		//			final FileInfoDefinition definition = createFileDefinition(xdefinition);
		//			Home.getNameSpace().registerDefinition(definition, FileInfoDefinition.class);
		//		}
	}
}
